@@ -1,6 +1,6 @@
 """Storage respone objects."""
 
-from typing import Any, Dict, Optional, Set
+from typing import Any, Mapping, Optional
 
 from requests import Response
 
@@ -13,13 +13,13 @@ from ambra_sdk.exceptions.storage import (
 
 def check_response(
     response: Response,
-    url_arg_names: Set[str],
-    errors_mapping: Optional[Dict[int, Any]] = None,
+    url: str,
+    errors_mapping: Optional[Mapping[int, Any]] = None,
 ) -> Response:
     """Check response on errors.
 
     :param response: response obj
-    :param url_arg_names: set of arguments in url
+    :param url: full url str
     :param errors_mapping: map of error name and exception
 
     :return: response object
@@ -41,11 +41,11 @@ def check_response(
         exception = errors_mapping[status_code]
         raise exception
     elif status_code == 404:
-        description = 'Url or some of {url_arg_names} is wrong' \
-            .format(url_arg_names=url_arg_names)
+        description = 'Url is wrong: {url}' \
+            .format(url=url)
         raise NotFound(description)
     elif status_code == 403:
-        description = 'Access denied. Wrong sid'
+        description = 'Access denied or wrong sid'
         raise PermissionDenied(description)
     raise AmbraResponseException(
         code=status_code,
